How Messaging Works
===================
This article will explain how the messaging system works, how the messaging 
system ensures that multiplayer games stay in sync (without lagging), how to 
make message classes, and how to make almost any component of the game engine 
react to messages.
